pub(crate) enum MediaCommand {
Delete {
mxc: OwnedMxcUri,
},
DeleteByEvent {
event_id: OwnedEventId,
},
DeleteList,
DeleteRange {
duration: String,
older_than: bool,
newer_than: bool,
yes_i_want_to_delete_local_media: bool,
},
DeleteAllFromUser {
username: String,
},
DeleteAllFromServer {
server_name: OwnedServerName,
yes_i_want_to_delete_local_media: bool,
},
GetFileInfo {
mxc: OwnedMxcUri,
},
GetRemoteFile {
mxc: OwnedMxcUri,
server: Option<OwnedServerName>,
timeout: u32,
},
GetRemoteThumbnail {
mxc: OwnedMxcUri,
server: Option<OwnedServerName>,
timeout: u32,
width: u32,
height: u32,
},
}Variants
Delete
- Deletes a single media file from our database and on the filesystem via a single MXC URL
Fields
mxc: OwnedMxcUriThe MXC URL to delete
DeleteByEvent
- Deletes media files referenced by event
Fields
event_id: OwnedEventId- The event ID which contains the media and thumbnail MXC URLs
DeleteList
- Deletes a codeblock list of MXC URLs from our database and on the filesystem. This will always ignore errors.
DeleteRange
- Deletes all remote (and optionally local) media created before or after [duration] time using filesystem metadata last modified at date.
Fields
DeleteAllFromUser
- Deletes all the local media from a local user on our server. This will always ignore errors by default.
DeleteAllFromServer
- Deletes all remote media from the specified remote server. This will always ignore errors by default.
Fields
server_name: OwnedServerNameGetFileInfo
Fields
mxc: OwnedMxcUriThe MXC URL to lookup info for.
GetRemoteFile
GetRemoteThumbnail