sorted_elapsed

Function sorted_elapsed 

fn sorted_elapsed(
    outcomes: &[Outcome<()>],
    select: impl Fn(Disposition) -> bool,
) -> Vec<Duration>
Collects the ascending elapsed times of the selected dispositions.

The statistics and histogram index the population, which forces the buffer.