pub(crate) enum RoomModerationCommand {
BanRoom {
room: OwnedRoomOrAliasId,
},
BanListOfRooms,
UnbanRoom {
room: OwnedRoomOrAliasId,
},
ListBannedRooms {
no_details: bool,
},
}Variants
BanRoom
- Bans a room from local users joining and evicts all our local users (including server admins) from the room. Also blocks any invites (local and remote) for the banned room, and disables federation entirely with it.
Fields
room: OwnedRoomOrAliasIdThe room in the format of !roomid:example.com or a room alias in
the format of #roomalias:example.com
BanListOfRooms
- Bans a list of rooms (room IDs and room aliases) from a newline
delimited codeblock similar to
user deactivate-all. Applies the same steps as ban-room
UnbanRoom
- Unbans a room to allow local users to join again
Fields
room: OwnedRoomOrAliasIdThe room in the format of !roomid:example.com or a room alias in
the format of #roomalias:example.com
ListBannedRooms
- List of all rooms we have banned