pub(crate) async fn parse_active_local_user_id(
services: &Services,
user_id: &str,
) -> Result<OwnedUserId>Expand description
Parses user ID that is an active (not guest or deactivated) local user.
An account with an empty password reads as deactivated, which is how a guest is refused along with a deactivated account.