pub(crate) enum DebugCommand {
Show 35 variants
Echo {
message: Vec<String>,
},
GetAuthChain {
event_id: OwnedEventId,
},
ParsePdu,
GetPdu {
event_id: OwnedEventId,
},
GetShortPdu {
shortroomid: ShortRoomId,
count: i64,
},
GetRemotePdu {
event_id: OwnedEventId,
server: OwnedServerName,
},
GetRemotePduList {
server: OwnedServerName,
force: bool,
},
GetRoomState {
room_id: OwnedRoomOrAliasId,
kind: Option<String>,
state_key: Option<String>,
},
GetSigningKeys {
server_name: Option<OwnedServerName>,
notary: Option<OwnedServerName>,
query: bool,
},
GetVerifyKeys {
server_name: Option<OwnedServerName>,
},
Ping {
server: OwnedServerName,
},
ForceDeviceListUpdates,
ChangeLogLevel {
filter: Option<String>,
reset: bool,
},
SignJson,
VerifyJson,
VerifyPdu {
event_id: OwnedEventId,
},
FirstPduInRoom {
room_id: OwnedRoomId,
},
LatestPduInRoom {
room_id: OwnedRoomId,
},
ForceSetRoomStateFromServer {
room_id: OwnedRoomId,
server_name: OwnedServerName,
},
ResolveTrueDestination {
server_name: OwnedServerName,
no_cache: bool,
},
MemoryStats {
opts: Option<String>,
},
RuntimeMetrics,
RuntimeInterval,
TaskMetrics,
TaskInterval,
Time,
ListDependencies {
names: bool,
},
DatabaseStats {
property: Option<String>,
map: Option<String>,
},
TrimMemory,
DatabaseFiles {
map: Option<String>,
level: Option<i32>,
},
CreateJwt {
user: String,
exp_from_now: Option<u64>,
nbf_from_now: Option<u64>,
issuer: Option<String>,
audience: Option<String>,
},
ResyncDatabase,
GetRetainedPdu {
event_id: OwnedEventId,
},
DumpPdus {
dir: String,
},
Tester(TesterCommand),
}Variants
Echo
- Echo input of admin command
GetAuthChain
- Get the auth_chain of a PDU
Fields
event_id: OwnedEventIdAn event ID (the $ character followed by the base64 reference hash)
ParsePdu
- Parse and print a PDU from a JSON
The PDU event is only checked for validity and is not added to the database.
This command needs a JSON blob provided in a Markdown code block below the command.
GetPdu
- Retrieve and print a PDU by EventID from the tuwunel database
Fields
event_id: OwnedEventIdAn event ID (a $ followed by the base64 reference hash)
GetShortPdu
- Retrieve and print a PDU by PduId from the tuwunel database
GetRemotePdu
- Attempts to retrieve a PDU from a remote server. Inserts it into our database/timeline if found and we do not have this PDU already (following normal event auth rules, handles it as an incoming PDU).
Fields
event_id: OwnedEventIdAn event ID (a $ followed by the base64 reference hash)
server: OwnedServerNameArgument for us to attempt to fetch the event from the specified remote server.
GetRemotePduList
- Same as
get-remote-pdubut accepts a codeblock newline delimited list of PDUs and a single server to fetch from
Fields
server: OwnedServerNameArgument for us to attempt to fetch all the events from the specified remote server.
GetRoomState
- Gets all the room state events for the specified room.
Fields
room_id: OwnedRoomOrAliasIdRoom ID
GetSigningKeys
- Get and display signing keys from local cache or remote server.
GetVerifyKeys
- Get and display signing keys from local cache or remote server.
Ping
- Sends a federation request to the remote server’s
/_matrix/federation/v1/versionendpoint and measures the latency it took for the server to respond
Fields
server: OwnedServerNameForceDeviceListUpdates
- Forces device lists for all local and remote users to be updated (as having new keys available)
ChangeLogLevel
- Change tracing log level/filter on the fly
This accepts the same format as the log config option.
Fields
SignJson
- Sign JSON blob
This command needs a JSON blob provided in a Markdown code block below the command.
VerifyJson
- Verify JSON signatures
This command needs a JSON blob provided in a Markdown code block below the command.
VerifyPdu
- Verify PDU
This re-verifies a PDU existing in the database found by ID.
Fields
event_id: OwnedEventIdFirstPduInRoom
- Prints the very first PDU in the specified room (typically m.room.create)
Fields
room_id: OwnedRoomIdThe room ID
LatestPduInRoom
- Prints the latest (“last”) PDU in the specified room (typically a message)
Fields
room_id: OwnedRoomIdThe room ID
ForceSetRoomStateFromServer
- Forcefully replaces the room state of our local copy of the specified room, with the copy (auth chain and room state events) the specified remote server says.
A common desire for room deletion is to simply “reset” our copy of the room. While this admin command is not a replacement for that, if you know you have split/broken room state and you know another server in the room that has the best/working room state, this command can let you use their room state. Such example is your server saying users are in a room, but other servers are saying they’re not in the room in question.
This command will get the latest PDU in the room we know about, and
request the room state at that point in time via
/_matrix/federation/v1/state/{roomId}.
Fields
room_id: OwnedRoomIdThe impacted room ID
server_name: OwnedServerNameThe server we will use to query the room state for
ResolveTrueDestination
- Runs a server name through tuwunel’s true destination resolution process
Useful for debugging well-known issues
MemoryStats
- Print extended memory usage
Optional argument is a character mask (a sequence of characters in any order) which enable additional extended statistics. Known characters are “abdeglmx”. For convenience, a ‘*’ will enable everything.
RuntimeMetrics
- Print general tokio runtime metric totals.
RuntimeInterval
- Print detailed tokio runtime metrics accumulated since last command invocation.
TaskMetrics
- Print detailed tokio task metrics accumulated in total.
TaskInterval
- Print detailed tokio task metrics accumulated since last command invocation.
Time
- Print the current time
ListDependencies
- List dependencies
DatabaseStats
- Get database statistics
TrimMemory
- Trim memory usage
DatabaseFiles
- List database files
CreateJwt
- Create a JWT token for login
Fields
ResyncDatabase
- Synchronize database with primary (secondary only)
GetRetainedPdu
- Retrieves the saved original PDU before it has been redacted
Fields
event_id: OwnedEventIdDumpPdus
- Dump all stored PDUs
Tester(TesterCommand)
- Developer test stubs