pub(crate) enum UserCommand {
Show 20 variants
CreateUser {
username: String,
password: Option<String>,
},
ResetPassword {
username: String,
password: Option<String>,
},
Deactivate {
no_leave_rooms: bool,
user_id: String,
},
DeactivateAll {
no_leave_rooms: bool,
force: bool,
},
DeleteDevice {
user_id: OwnedUserId,
device_id: OwnedDeviceId,
},
LastActive {
limit: Option<usize>,
},
ListUsers,
ListJoinedRooms {
user_id: String,
},
ForceJoinRoom {
user_id: String,
room: OwnedRoomOrAliasId,
},
ForceLeaveRoom {
user_id: String,
room_id: OwnedRoomOrAliasId,
},
RejectInvites {
user_id: String,
reason: Option<String>,
},
ForceDemote {
user_id: String,
room_id: OwnedRoomOrAliasId,
},
ForcePromote {
user_id: String,
room_id: OwnedRoomOrAliasId,
},
MakeUserAdmin {
user_id: String,
},
PutRoomTag {
user_id: String,
room_id: OwnedRoomId,
tag: String,
},
DeleteRoomTag {
user_id: String,
room_id: OwnedRoomId,
tag: String,
},
GetRoomTags {
user_id: String,
room_id: OwnedRoomId,
},
RedactEvent {
event_id: OwnedEventId,
},
ForceJoinListOfLocalUsers {
room: OwnedRoomOrAliasId,
yes_i_want_to_do_this: bool,
},
ForceJoinAllLocalUsers {
room: OwnedRoomOrAliasId,
yes_i_want_to_do_this: bool,
},
}Variants
CreateUser
- Create a new user
Fields
ResetPassword
- Reset user password
Fields
Deactivate
- Deactivate a user
User will be removed from all rooms by default. Use –no-leave-rooms to not leave all rooms by default.
DeactivateAll
- Deactivate a list of users
Recommended to use in conjunction with list-local-users.
Users will be removed from joined rooms by default.
Can be overridden with –no-leave-rooms.
Removing a mass amount of users from a room may cause a significant amount of leave events. The time to leave rooms may depend significantly on joined rooms and servers.
This command needs a newline separated list of users provided in a Markdown code block below the command.
Fields
DeleteDevice
- Deletes a user’s device.
LastActive
- List local users by recent activity.
ListUsers
- List local users in the database
ListJoinedRooms
- Lists all the rooms (local and remote) that the specified user is joined in
ForceJoinRoom
- Manually join a local user to a room.
ForceLeaveRoom
- Manually leave a local user from a room.
RejectInvites
- Reject all pending invites for a local user.
ForceDemote
- Forces the specified user to drop their power levels to the room default, if their permissions allow and the auth check permits
ForcePromote
- Force promote
MakeUserAdmin
- Grant server-admin privileges to a user.
PutRoomTag
- Puts a room tag for the specified user and room ID.
This is primarily useful if you’d like to set your admin room
to the special “System Alerts” section in Element as a way to
permanently see your admin room without it being buried away in your
favourites or rooms. To do this, you would pass your user, your admin
room’s internal ID, and the tag name m.server_notice.
DeleteRoomTag
- Deletes the room tag for the specified user and room ID
GetRoomTags
- Gets all the room tags for the specified user and room ID
RedactEvent
- Attempts to forcefully redact the specified event ID from the sender user
This is only valid for local users
Fields
event_id: OwnedEventIdForceJoinListOfLocalUsers
- Force joins a specified list of local users to join the specified room.
Specify a codeblock of usernames.
Requires the --yes-i-want-to-do-this flag.
ForceJoinAllLocalUsers
- Force joins all local users to the specified room.
Requires the --yes-i-want-to-do-this flag.